@@ -6,13 +6,14 @@
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#ifndef AKONADI_CONTACTVIEWERDIALOG_H
-#define AKONADI_CONTACTVIEWERDIALOG_H
+#pragma once
 
 #include "akonadi-contact_export.h"
 
 #include <QDialog>
 
+#include <memory>
+
 namespace KContacts
 {
 }
@@ -22,6 +23,7 @@ namespace Akonadi
 class Item;
 
 class ContactViewer;
+class ContactViewerDialogPrivate;
 
 /**
  * @short A dialog for displaying a contact in Akonadi.
@@ -81,10 +83,8 @@ public Q_SLOTS:
 
 private:
     //@cond PRIVATE
-    class Private;
-    Private *const d;
+    std::unique_ptr<ContactViewerDialogPrivate> const d;
     //@endcond
 };
 }
 
-#endif
